@@ -104,6 +104,9 @@ DBusMessage *reply;
   if (bus == spi_global_app_data->bus)
     spi_atk_add_client (dbus_message_get_sender (msg));
 
+  if (!spi_global_app_data->app_bus_addr)
+    spi_atk_create_socket (spi_global_app_data);
+
 reply = dbus_message_new_method_return(msg);
 if (reply)
     {
